
## Debugging common issues with a TMC Self Managed installation
**Prerequisites**
- A machine having access to the TMC SM kubernetes cluster.

### Basic Troubleshooting

All the components of TMC SM are deployed in a namespace named "tmc-local". You can list all running pods as below.
```bash
kubectl -n tmc-local get pods
```
Observe the "STATUS" column, here all the pods should be in "Running" or "Completed" state. If you see any other status
eg. "Failed", "CrashLoopBackOff" then you can see more details on why it is failing by issuing below command.
```bash
kubectl -n tmc-local describe po <pod-name>
# eg.
kubectl -n tmc-local describe po wcm-server-545845b58-8d4dp
```
You will find the error message(if any) in the "Events" section of above output. If you don't see anything relevant then
you can check the logs from pods like below.
```bash
kubectl -n tmc-local logs wcm-server-545845b58-8d4dp

# keep streaming new logs
kubectl -n tmc-local logs wcm-server-545845b58-8d4dp -f

# Stream logs from all pods matching label `app=resource-manager`. 
# This may be helpful somtimes when you have two or more replicas of a pod running
kubectl -n tmc-local logs -l app=resource-manager -f 
```

### Viewing external requests
All external traffic flows into TMC via "envoy" https://www.envoyproxy.io/ a reverse-proxy. Which can receive traffic from
a load-balancer in your infrastructure (see traffic flow diagram). You see this traffic by tapping the logs from envoy pods.
```bash
kubectl -n tmc-local logs -c envoy -l app.kubernetes.io/component=envoy -f
```

Envoy then routes this traffic to the appropriate service(pods) based on path prefix matching. You can see those details from
the stack HTTPProxy object as follows.
```bash
kubectl -n tmc-local get httpproxy stack-http-proxy -o yaml
```

### Common issues:
#### 1. **"no healthy upstream" errors in apis or in envoy logs.**
This can mainly be caused due to below reasons.
1. Check if all the pods in tmc-local namespace are in "Running" or "Completed" state. If they are not then try to dig
    into the reason why those pods are not running.
2. If all pods looks healthy, you can try restarting "Contour" and "Envoy" pods using below command
```bash
kubectl -n tmc-local get po -l app.kubernetes.io/name=contour
```


    

